Rule

Enum Rule 

pub enum Rule {
Show 129 variants EOI, WHITESPACE, COMMENT, lparen, rparen, lbrace, rbrace, lbracket, rbracket, comma, dot, colon, equal, bang, at, arrow, integer, float, hex_seq, string_lit, source_loc, ident, name, qualified_name, value_ref, block_ref, stack_slot, dyn_stack_slot, dyn_type, global_value, mem_type, constant, func_ref, sig_ref, user_ref, user_name_ref, base_name, member_access, cast_args, callable_expr, exception_table, exception_tag, try_ret, try_exn, storage_slot, mapping_ref, context_var, event_ref, position_marker, visual_cue, visual_cue_ascii, visual_marker, analysis_comment, ty_int, ty_bytes_fixed, ty_scalar, ty_vector, ty_array, ty_base, ty, ty_mapping, ty_simple, immediate, value, test_directive, target_spec, module, contract_def, contract_body, storage_layout, storage_slot_decl, param, param_list, return_type, signature, function, visibility_modifier, mutability_modifier, entity_gv, entity_fn, entity_sig, entity_ss, entity_dss, entity_const, entity_decl, block_param, block_param_list, block_params, block_label, block, result, result_list, mem_operand, block_arg, operand, inline_const, operand_list, mem_flag, mem_flags, ty_suffix, inst_annot, opcode_binop, opcode_cmp, opcode_load, opcode_store, opcode_branch, opcode_call, opcode_convert, opcode_vector, opcode_thalir, opcode_other, opcode, cmp_cond, fcmp_cond, inst_binop, inst_cmp, inst_fcmp, inst_load, inst_store, inst_brif, inst_jump, inst_return, call_modifier, arg_list_call, inst_call, inst_convert, inst_generic, expr_tail, instruction,
}

Variants



EOI

End-of-input



WHITESPACE



COMMENT



lparen



rparen



lbrace



rbrace



lbracket



rbracket



comma



dot



colon



equal



bang



at



arrow



integer



float



hex_seq



string_lit



source_loc



ident



name



qualified_name



value_ref



block_ref



stack_slot



dyn_stack_slot



dyn_type



global_value



mem_type



constant



func_ref



sig_ref



user_ref



user_name_ref



base_name



member_access



cast_args



callable_expr



exception_table



exception_tag



try_ret



try_exn



storage_slot



mapping_ref



context_var



event_ref



position_marker



visual_cue



visual_cue_ascii



visual_marker



analysis_comment



ty_int



ty_bytes_fixed



ty_scalar



ty_vector



ty_array



ty_base



ty



ty_mapping



ty_simple



immediate



value



test_directive



target_spec



module



contract_def



contract_body



storage_layout



storage_slot_decl



param



param_list



return_type



signature



function



visibility_modifier



mutability_modifier



entity_gv



entity_fn



entity_sig



entity_ss



entity_dss



entity_const



entity_decl



block_param



block_param_list



block_params



block_label



block



result



result_list



mem_operand



block_arg



operand



inline_const



operand_list



mem_flag



mem_flags



ty_suffix



inst_annot



opcode_binop



opcode_cmp



opcode_load



opcode_store



opcode_branch



opcode_call



opcode_convert



opcode_vector



opcode_thalir



opcode_other



opcode



cmp_cond



fcmp_cond



inst_binop



inst_cmp



inst_fcmp



inst_load



inst_store



inst_brif



inst_jump



inst_return



call_modifier



arg_list_call



inst_call



inst_convert



inst_generic



expr_tail



instruction

Implementations

Source

impl Rule

pub fn all_rules() -> &'static [Rule]